@@ -5,23 +5,23 @@
 # This script automates creating universal binaries of LyX on Mac.
 # Author: Bennett Helm (and extended by Konrad Hofbauer)
 # latest changes by Stephan Witt
-# Last modified: January 2013
+# Last modified: February 2020
 
-Qt4API=${Qt4API:-"-cocoa"}
-Qt4Version=${Qt4Version:-"4.6.3"}
-Qt4SourceVersion="qt-everywhere-opensource-src-${Qt4Version}"
-Qt4BuildSubDir="qt-${Qt4Version}-build${Qt4API}"
-Qt4ConfigureOptions=${Qt4ConfigureOptions:-"-release"}
-
-GettextVersion=${GettextVersion:-"0.18.2"}
-GettextSource="gettext-${GettextVersion}"
-GettextLibrary="libintl.8.dylib"
+QtAPI=${QtAPI:-"-cocoa"}
+QtVersion=${QtVersion:-"4.6.3"}
+QtSourceVersion=${QtSourceVersion:-"qt-everywhere-opensource-src-${QtVersion}"}
+QtBuildSubDir="qt-${QtVersion}-build${QtAPI}"
+QtConfigureOptions=${QtConfigureOptions:-"-release"}
+QtSkipComponents=${QtSkipComponents:-"qtconnectivity qtscript qtquickcontrols qtmultimedia qtvirtualkeyboard qtwayland qtwebengine"}
+LibMagicVersion=${LibMagicVersion:-"5.19"}
+LibMagicSource="file-${LibMagicVersion}"
+LibMagicLibrary="libmagic.1.dylib"
 
 ASpellVersion=${ASpellVersion:-"0.60.6.1"}
 ASpellSource="aspell-${ASpellVersion}"
 ASpellLibrary="libaspell.15.dylib"
 
-HunSpellVersion=${HunSpellVersion:-"1.3.2"}
+HunSpellVersion=${HunSpellVersion:-"1.3.3"}
 HunSpellSource="hunspell-${HunSpellVersion}"
 HunSpellLibrary="libhunspell-1.3.0.dylib"
 
@@ -29,60 +29,88 @@ unset DYLD_LIBRARY_PATH LD_LIBRARY_PATH
 
 # Prerequisite:
 # * a decent checkout of LyX sources (probably you have it already)
-# * Qt4 - build with shared or static libraries for the used platforms (default: i386 and ppc)
-#    or - an unpacked source tree of Qt4 in $QT4SOURCEDIR or in the sibling directory (variable Qt4SourceVersion)
+# * Qt - build with shared or static libraries for the used platforms (default: i386 and ppc)
+#   or - an unpacked source tree of Qt in $QTSOURCEDIR or in the sibling directory (variable QtSourceVersion)
 # * for aspell support:
 #   the aspell sources placed in a sibling directory (variable ASpellSource)
 # * for hunspell support:
 #   the hunspell sources placed in a sibling directory (variable HunSpellSource)
-# * for dictionary deployment (per default thesauri only):
+# * for dictionary deployment (only hunspell dicts and mythes thesauri are deployed per default):
 #   - aspell:   the dictionary files of macports (in /opt/local/share/aspell and /opt/local/lib/aspell-0.60)
 #   - hunspell: the dictionary files in the sibling directory dictionaries/dicts
 #   - mythes:   the data and idx files in the sibling directory dictionaries/thes
+# * for magic file type detection support:
+#   the libmagic sources placed in a sibling directory (variable LibMagicSource)
 
 LyXConfigureOptions="--enable-warnings --enable-optimization=-Os --with-x=no"
 LyXConfigureOptions="${LyXConfigureOptions} --disable-stdlib-debug"
 AspellConfigureOptions="--enable-warnings --enable-optimization=-O0 --enable-debug --disable-nls --enable-compile-in-filters --disable-pspell-compatibility"
 HunspellConfigureOptions="--with-warnings --disable-nls --disable-static"
-Qt4ConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -fast -no-exceptions"
-Qt4ConfigureOptions="${Qt4ConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
-Qt4ConfigureOptions="${Qt4ConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
-Qt4DmgSuffix=qt4${Qt4API}.dmg
 
+QtMajorVersion=qt4
+QtConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -confirm-license"
 # stupid special case...
-case "${Qt4Version}:${Qt4API}" in
+case "${QtVersion}:${QtAPI}" in
 4.6*:-carbon)
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-exceptions"
+	QtConfigureOptions="${QtConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	for arch in ${ARCH_LIST} ; do
+		QTARCHS="${QTARCHS} -arch ${arch}"
+	done
 	;;
 5.0*)
-	Qt4ConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -fast -no-strip"
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} -no-javascript-jit -no-pkg-config"
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
-	Qt4DmgSuffix=qt5${Qt4API}.dmg
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-javascript-jit -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	QtMajorVersion=qt5
+	;;
+5.6*|5.7*)
+	QtConfigureOptions="${QtConfigureOptions} -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-kms -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake tools"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtconnectivity -skip qtscript"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtquickcontrols"
+	QtConfigureOptions="${QtConfigureOptions} -skip qttools"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtdeclarative"
+	QtMajorVersion=qt5
 	;;
 5.*)
-	Qt4DmgSuffix=qt5${Qt4API}.dmg
+	QtConfigureOptions="${QtConfigureOptions} -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-kms -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake tools"
+	for component in ${QtSkipComponents} ; do
+		QtConfigureOptions="${QtConfigureOptions} -skip ${component}"
+	done
+	QtMajorVersion=qt5
 	;;
 *)
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} ${Qt4API}"
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-exceptions"
+	QtConfigureOptions="${QtConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	QtConfigureOptions="${QtConfigureOptions} ${QtAPI}"
+	for arch in ${ARCH_LIST} ; do
+		QTARCHS="${QTARCHS} -arch ${arch}"
+	done
 	;;
 esac
 
 aspell_dictionaries="no"
 hunspell_dictionaries="yes"
 
-gettext_deployment="no"
+libmagic_deployment="yes"
 aspell_deployment="yes"
 hunspell_deployment="yes"
 thesaurus_deployment="yes"
 
-qt4_deployment="yes"
+qt_deployment="yes"
 
 # auto detect Xcode location
-if [ -d "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs" ]; then
-	DEVELOPER_SDKS="/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs"
-	XCODE_DEVELOPER="/Applications/Xcode.app/Contents/Developer"
+DEVELOPER_SDKS=$(dirname $(xcrun --show-sdk-path))
+if [ -n "${DEVELOPER_SDKS}" ]; then
+	XCODE_DEVELOPER=$(dirname $(dirname $(xcrun --show-sdk-platform-path)))
 	MACOSX_DEPLOYMENT_TARGET="10.7" # Lion support is default
-	SDKROOT="${DEVELOPER_SDKS}/MacOSX10.7.sdk" # Lion build is default
+	SDKROOT="${DEVELOPER_SDKS}/MacOSX$(xcrun --show-sdk-version).sdk" # use default SDK
 elif [ -d "/Developer/SDKs" ]; then
 	DEVELOPER_SDKS="/Developer/SDKs"
 	XCODE_DEVELOPER="/Developer"
@@ -116,22 +144,29 @@ usage() {
 	echo
 	echo Optional arguments:
 	echo " --aspell-deployment=yes|no ." default yes
-	echo " --with-qt4-frameworks=yes|no" default no
-	echo " --qt4-deployment=yes|no ...." default yes
+	echo " --with-qt-frameworks=yes|no." default no
+	echo " --qt-deployment=yes|no ....." default yes
 	echo " --with-macosx-target=TARGET " default 10.4 "(Tiger)"
 	echo " --with-sdkroot=SDKROOT ....." default 10.5 "(Leopard)"
 	echo " --with-arch=ARCH ..........." default ppc,i386
 	echo " --with-build-path=PATH ....." default \${lyx-src-dir}/../lyx-build
 	echo " --with-dmg-location=PATH ..." default \${build-path}
+	echo " --with-binary-strip=yes ...." default no
+	echo " --codesign-identity=CSID ..." default is w/o CSID
 	echo
 	echo "All other arguments with -- are passed to configure"
 	echo "including the defaults: ${LyXConfigureOptions}"
-	if [ -x "${LyxSourceDir}/configure" ]; then
-		echo
-		echo "*" Configure options of LyX
-		echo
-		"${LyxSourceDir}/configure" --help
-	fi
+	case "${1}" in
+	--help=short)
+		;;
+	*)
+		if [ -x "${LyxSourceDir}/configure" ]; then
+			echo
+			echo "*" Configure options of LyX
+			echo
+			"${LyxSourceDir}/configure" --help
+		fi
+	esac
 	exit 0
 }
 
@@ -143,15 +178,15 @@ fi
 
 while [ $# -gt 0 ]; do
 	case "${1}" in
-	--with-qt4-frameworks=*)
-		configure_qt4_frameworks=$(echo ${1}|cut -d= -f2)
-		if [ "$configure_qt4_frameworks" = "yes" ]; then
+	--with-qt-frameworks=*)
+		configure_qt_frameworks=$(echo ${1}|cut -d= -f2)
+		if [ "$configure_qt_frameworks" = "yes" ]; then
 			unset QTDIR
-			qt4_deployment="no"
+			qt_deployment="no"
 		fi
 		shift
 		;;
-	--with-qt4-dir=*)
+	--with-qt-dir=*)
 		QTDIR=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
@@ -168,17 +203,22 @@ while [ $# -gt 0 ]; do
 			export OBJC=gcc-4.0
 			export CXX=g++-4.0
 			;;
-		10.5|10.6|10.7|10.8)
-			SDKROOT="${DEVELOPER_SDKS}/MacOSX${SDKROOT}.sdk"
-			;;
 		*)
-			usage
+			SDKROOT="${DEVELOPER_SDKS}/MacOSX${SDKROOT}.sdk"
+			if [ ! -d "${SDKROOT}" ]; then
+				echo Invalid SDKROOT given: "${SDKROOT}"
+				usage --help=short
+			fi
 			;;
 		esac
 		shift
 		;;
-	--gettext-deployment=*)
-		gettext_deployment=$(echo ${1}|cut -d= -f2)
+	--codesign-identity=*)
+		CODESIGN_IDENTITY=$(echo "${1}"|cut -d= -f2)
+		shift
+		;;
+	--libmagic-deployment=*)
+		libmagic_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
 	--aspell-deployment=*)
@@ -195,8 +235,8 @@ while [ $# -gt 0 ]; do
 		thesaurus_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
-	--qt4-deployment=*)
-		qt4_deployment=$(echo ${1}|cut -d= -f2)
+	--qt-deployment=*)
+		qt_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
 	--with-arch=*)
@@ -208,6 +248,10 @@ while [ $# -gt 0 ]; do
 		DMGLocation=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
+	--with-binary-strip=yes)
+		strip="-strip"
+		shift
+		;;
 	--with-build-path=*)
 		LyxBuildDir=$(echo ${1}|cut -d= -f2)
 		shift
@@ -217,7 +261,7 @@ while [ $# -gt 0 ]; do
 		shift
 		;;
 	--help|--help=*)
-		usage
+		usage "${1}"
 		;;
 	--without-aspell)
 		LyXConfigureOptions="${LyXConfigureOptions} ${1}"
@@ -229,10 +273,19 @@ while [ $# -gt 0 ]; do
 		hunspell_deployment="no"
 		shift
 		;;
+	--only-qt*=*)
+		QtOnlyPackage=$(echo ${1}|cut -d= -f2)
+		shift
+		;;
 	--only-package=*)
 		LyxOnlyPackage=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
+	--enable-cxx11)
+		LyXConfigureOptions="${LyXConfigureOptions} ${1}"
+		EnableCXX11="--enable-cxx11"
+		shift
+		;;
 	--*)
 		LyXConfigureOptions="${LyXConfigureOptions} ${1}"
 		shift
@@ -243,13 +296,12 @@ while [ $# -gt 0 ]; do
 	esac
 done
 
-if [ "${configure_qt4_frameworks}" != "yes" ]; then
+if [ "${configure_qt_frameworks}" != "yes" ]; then
 	QtInstallDir=${QTDIR:-"/opt/qt4"}
 fi
 
 ARCH_LIST=${ARCH_LIST:-"ppc i386"}
 
-strip="-strip"
 aspellstrip=
 
 LyxBuildDir=${LyxBuildDir:-$(dirname "${LyxSourceDir}")/lyx-build}
@@ -257,10 +309,10 @@ DMGLocation=${DMGLocation:-"${LyxBuildDir}"}
 
 LyXUtilitiesDir=${LyXUtilitiesDir:-"${LyxBuildDir}"/utilities}
 
-GettextSourceDir=${GETTEXTDIR:-$(dirname "${LyxSourceDir}")/${GettextSource}}
-GettextBuildDir="${LyxBuildDir}"/"${GettextSource}"
-GettextInstallDir=${GettextInstallDir:-"${LyXUtilitiesDir}"}
-GettextInstallHdr="${GettextInstallDir}/include/libintl.h"
+LibMagicSourceDir=${LIBMAGICDIR:-$(dirname "${LyxSourceDir}")/${LibMagicSource}}
+LibMagicBuildDir="${LyxBuildDir}"/"${LibMagicSource}"
+LibMagicInstallDir=${LibMagicInstallDir:-"${LyXUtilitiesDir}"}
+LibMagicInstallHdr="${LibMagicInstallDir}/include/magic.h"
 
 ASpellSourceDir=${ASPELLDIR:-$(dirname "${LyxSourceDir}")/${ASpellSource}}
 ASpellBuildDir="${ASpellSourceDir}"
@@ -272,17 +324,22 @@ HunSpellBuildDir="${HunSpellSourceDir}"
 HunSpellInstallDir=${HunSpellInstallDir:-"${LyXUtilitiesDir}"}
 HunSpellInstallHdr="${HunSpellInstallDir}/include/hunspell/hunspell.h"
 
-Qt4SourceDir=${QT4SOURCEDIR:-$(dirname "${LyxSourceDir}")/${Qt4SourceVersion}}
-Qt4BuildDir=${Qt4BuildDir:-"${LyxBuildDir}"/${Qt4BuildSubDir:-"qt4-build"}}
+QtSourceDir=${QTSOURCEDIR:-$(dirname "${LyxSourceDir}")/${QtSourceVersion}}
+QtBuildDir=${QtBuildDir:-"${LyxBuildDir}"/${QtBuildSubDir:-"qt-build"}}
 
 DictionarySourceDir=${DICTIONARYDIR:-$(dirname "${LyxSourceDir}")/dictionaries}
 DocumentationDir=$(dirname "${LyxSourceDir}")/Documents
 DmgBackground="${LyxSourceDir}"/development/MacOSX/dmg-background.png
 
 if [ -z "${LyXVersion}" ]; then
-	LyXVersion=$(grep AC_INIT "${LyxSourceDir}"/configure.ac | cut -d, -f2 | tr -d " ()")
+	LyXVersion=$(grep AC_INIT "${LyxSourceDir}"/configure.ac | cut -d, -f2 | tr -d " []()")
 fi
 LyXVersionSuffix=${LyXVersionSuffix:-$(echo "${LyXVersion}" | cut -d. -f1-2)}
+case "${LyXVersion}" in
+*dev*)
+	LyXGitCommitHash=$(cd "${LyxSourceDir}" ; git log -1 --pretty=format:%h)
+	;;
+esac
 
 LyxName="LyX"
 LyxBase="${LyxName}-${LyXVersion}"
@@ -298,26 +355,30 @@ LyxAppPrefix="${LyxAppDir}.app"
 # ---------------------------------
 
 # don't change order here...
-case "${Qt4Version}" in
+case "${QtVersion}" in
 5.0.*|5.1.*)
-	QtLibraries="QtSvg QtXml QtPrintSupport QtWidgets QtGui QtNetwork QtConcurrent QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtPrintSupport QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
+	QtFrameworkVersion="5"
+	;;
+5.12.*)
+	QtLibraries=${QtLibraries:-"QtDBus QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
 	QtFrameworkVersion="5"
 	;;
 5*)
-	QtLibraries="QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
 	QtFrameworkVersion="5"
 	;;
 *)
-	QtLibraries="QtSvg QtXml QtGui QtNetwork QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtGui QtNetwork QtCore"}
 	QtFrameworkVersion="4"
 	;;
 esac
 
-DMGNAME="${LyxBase}"
+DMGNAME="${LyxBase}${LyXGitCommitHash:+-}${LyXGitCommitHash}"
 DMGSIZE="550m"
 
 # Check for existing SDKs
-SDKs=$(echo ${DEVELOPER_SDKS}/MacOSX10*sdk)
+SDKs=$(echo ${DEVELOPER_SDKS}/MacOSX1[01]*sdk)
 case $SDKs in
 *${SDKROOT}*)
 	;;
@@ -342,79 +403,80 @@ case $SDKs in
 	;;
 esac
 MYCFLAGS="-mmacosx-version-min=${MACOSX_DEPLOYMENT_TARGET}"
+MYLDFLAGS="-mmacosx-version-min=${MACOSX_DEPLOYMENT_TARGET}"
 
-# pkg-config is not usable with this script
-export PKG_CONFIG=""
-
-# These variables define the identifiers of the
-# system (both Intel and PowerPC) to compile for.
-# (Note: darwin8 is 10.4; darwin9 is 10.5.)
-# Only change these if necessary
-
-HostSystem_i386="i686-apple-darwin8"
-HostSystem_ppc="powerpc-apple-darwin8"
-
-if [ "${configure_qt4_frameworks}" != "yes" -a -d "${Qt4SourceDir}" -a ! \( -d "${Qt4BuildDir}" -a -d "${QtInstallDir}" \) ]; then
-	echo Build Qt4 library ${Qt4SourceDir}
-	if [ "${QtInstallDir}" = "${Qt4BuildDir}" ]; then
+build_qt() {
+	echo Build Qt library ${QtSourceDir}
+	if [ "${QtInstallDir}" = "${QtBuildDir}" ]; then
 		echo Bad install directory for Qt.
-		echo Must be different from build directory "${Qt4BuildDir}".
+		echo Must be different from build directory "${QtBuildDir}".
 		exit 1
 	fi
 	(
-		mkdir -p "${Qt4BuildDir}" && cd "${Qt4BuildDir}"
-		for arch in ${ARCH_LIST} ; do
-			ARCHS="${ARCHS} -arch ${arch}"
-		done
+		mkdir -p "${QtBuildDir}" && cd "${QtBuildDir}"
 		echo configure options:
-		echo ${Qt4ConfigureOptions} ${ARCHS} -prefix "${QtInstallDir}"
-		echo yes | "${Qt4SourceDir}"/configure ${Qt4ConfigureOptions} ${ARCHS} -prefix "${QtInstallDir}"
-		make ${MAKEJOBS} && make install
+		echo ${QtConfigureOptions} ${QTARCHS} -prefix "${QtInstallDir}"
+		"${QtSourceDir}"/configure ${QtConfigureOptions} ${QTARCHS} -prefix "${QtInstallDir}"
+		make -j1 && make -j1 install
 	)
-	cd "${QtInstallDir}" && (
-		mkdir -p include
-		cd include
-		for libnm in ${QtLibraries} ; do
-			test -d ${libnm} -o -L ${libnm} || ln -s ../lib/${libnm}.framework/Headers ${libnm}
-		done
-	)
-fi
+	if [ -d "${QtInstallDir}" -a ! -f "${QtInstallDir}"/include/QtCore ]; then
+		cd "${QtInstallDir}" && (
+			mkdir -p include
+			cd include
+			for libnm in ${QtLibraries} ; do
+				test -d ${libnm} -o -L ${libnm} || \
+				( ln -s ../lib/${libnm}.framework/Headers ${libnm} && echo Link to framework ${libnm} )
+			done
+		)
+	fi
+}
 
-if [ -d "${GettextSourceDir}" -a ! -f "${GettextInstallHdr}" ]; then
-	# we have a private Gettext source tree at hand...
+case ${QtOnlyPackage:-"no"} in
+y*)
+	build_qt
+	exit 0
+	;;
+*)
+	if [ "${configure_qt_frameworks}" != "yes" -a -d "${QtSourceDir}" -a ! \( -d "${QtBuildDir}" -a -d "${QtInstallDir}" \) ]; then
+		build_qt
+	fi
+	;;
+esac
+
+if [ -d "${LibMagicSourceDir}" -a ! -f "${LibMagicInstallHdr}" ]; then
+	# we have a private libmagic (file(1)) source tree at hand...
 	# so let's build and install it
-	if [ -z "${GettextVersion}" ]; then
-		GettextVersion=$(grep AC_INIT "${GettextSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+	if [ -z "${LibMagicVersion}" ]; then
+		LibMagicVersion=$(grep AC_INIT "${LibMagicSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
-	GettextName="Gettext"
-	GettextBase="${GettextName}-${GettextVersion}"
+	LibMagicName="LibMagic"
+	LibMagicBase="${LibMagicName}-${LibMagicVersion}"
 
-	echo Build gettext library ${GettextBase}
+	echo Build libmagic library ${LibMagicBase}
 	echo configure options:
-	echo --prefix="${GettextInstallDir}" ${GettextConfigureOptions}
+	echo --prefix="${LibMagicInstallDir}" ${LibMagicConfigureOptions}
 
-	mkdir -p "${GettextBuildDir}" && cd "${GettextBuildDir}"
+	mkdir -p "${LibMagicBuildDir}" && cd "${LibMagicBuildDir}"
 
 	# ----------------------------------------
-	# Build Gettext for different architectures
+	# Build LibMagic for different architectures
 	# ----------------------------------------
-	FILE_LIST="${GettextLibrary}"
+	FILE_LIST="${LibMagicLibrary}"
 
 	for arch in ${ARCH_LIST} ; do
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
-		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
-		"${GettextSourceDir}/configure"\
-			--prefix="${GettextInstallDir}"\
-			${GettextConfigureOptions}
+		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYLDFLAGS}"; export LDFLAGS
+		"${LibMagicSourceDir}/configure"\
+			--prefix="${LibMagicInstallDir}"\
+			${LibMagicConfigureOptions}
 		make && make install${strip}
 		for file in ${FILE_LIST} ; do
-			if [ -f "${GettextInstallDir}"/lib/${file} ]; then
-				mv "${GettextInstallDir}"/lib/${file}\
-					"${GettextInstallDir}"/lib/${file}-${arch} 
+			if [ -f "${LibMagicInstallDir}"/lib/${file} ]; then
+				mv "${LibMagicInstallDir}"/lib/${file}\
+					"${LibMagicInstallDir}"/lib/${file}-${arch} 
 			else
-				echo Cannot build and install Gettext for ${arch}.
+				echo Cannot build and install LibMagic for ${arch}.
 				exit 1
 			fi
 		done
@@ -428,15 +490,17 @@ if [ -d "${GettextSourceDir}" -a ! -f "${GettextInstallHdr}" ]; then
 			OBJ_LIST="${OBJ_LIST} lib/${file}-${arch}"
 		done
 		(
-			cd "${GettextInstallDir}"
+			cd "${LibMagicInstallDir}"
 			lipo -create ${OBJ_LIST} -o lib/${file}
+			# check for the "missing link"...
+			test -f lib/libmagic.dylib || (cd lib ; ln -s "${LibMagicLibrary}" libmagic.dylib)
 		)
 	done
 	# --------
 	# Clean up
 	# --------
 	for arch in ${ARCH_LIST} ; do
-		rm -f "${GettextInstallDir}"/lib/*-${arch}
+		rm -f "${LibMagicInstallDir}"/lib/*-${arch}
 	done
 fi
 
@@ -444,7 +508,7 @@ if [ -d "${HunSpellSourceDir}" -a ! -f "${HunSpellInstallHdr}" ]; then
 	# we have a private HunSpell source tree at hand...
 	# so let's build and install it
 	if [ -z "${HunSpellVersion}" ]; then
-		HunSpellVersion=$(grep AC_INIT "${HunSpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+		HunSpellVersion=$(grep AC_INIT "${HunSpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
 	HunSpellName="Hunspell"
@@ -464,8 +528,7 @@ if [ -d "${HunSpellSourceDir}" -a ! -f "${HunSpellInstallHdr}" ]; then
 	for arch in ${ARCH_LIST} ; do
 		make distclean
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
-		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
+		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYLDFLAGS}"; export LDFLAGS
 		"${HunSpellSourceDir}/configure"\
 			--prefix="${HunSpellInstallDir}"\
 			${HunspellConfigureOptions}
@@ -507,7 +570,7 @@ if [ -d "${ASpellSourceDir}" -a ! -f "${ASpellInstallHdr}" -a "yes" = "${aspell_
 	# we have a private ASpell source tree at hand...
 	# so let's build and install it
 	if [ -z "${ASpellVersion}" ]; then
-		ASpellVersion=$(grep AC_INIT "${ASpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+		ASpellVersion=$(grep AC_INIT "${ASpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
 	ASpellName="Aspell"
@@ -528,8 +591,7 @@ if [ -d "${ASpellSourceDir}" -a ! -f "${ASpellInstallHdr}" -a "yes" = "${aspell_
 	for arch in ${ARCH_LIST} ; do
 		make distclean
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
-		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
+		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYLDFLAGS}"; export LDFLAGS
 		CXXFLAGS=-g "${ASpellSourceDir}/configure"\
 			--prefix="${ASpellInstallDir}"\
 			${AspellConfigureOptions}
@@ -570,13 +632,25 @@ framework_name() {
 	echo "Frameworks/${1}.framework"
 }
 
-LYX_FILE_LIST="lyx lyxclient tex2lyx"
+LYX_FILE_LIST="lyx lyxclient tex2lyx lyxconvert"
 BUNDLE_PATH="Contents/MacOS"
 LYX_BUNDLE_PATH="${LyxAppPrefix}/${BUNDLE_PATH}"
+
 build_lyx() {
 	# Clear Output
 	if [ -n "${LyxAppZip}" -a -f "${LyxAppZip}" ]; then rm "${LyxAppZip}"; fi
-	if [ -d "${LyxAppPrefix}" ]; then rm -rf "${LyxAppPrefix}"; fi
+	if [ -d "${LyxAppPrefix}" ]; then
+		find "${LyxAppPrefix}" -type d -exec chmod u+w '{}' \;
+		rm -rf "${LyxAppPrefix}"
+	fi
+
+	case "${EnableCXX11}" in
+	"--enable-cxx11")
+		export CC=cc
+		export CXX="c++ -stdlib=libc++"
+		export CXXFLAGS=-std=c++11
+		;;
+	esac
 
 	# -------------------------------------
 	# Automate configure check
@@ -617,14 +691,13 @@ build_lyx() {
 		mkdir -p "${LyxBuildDir}" && cd "${LyxBuildDir}"
 
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"
-		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
+		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYLDFLAGS} -F${QtInstallDir}/lib"
 
-		if [ "$configure_qt4_frameworks" = "yes" ]; then
-			export QT4_CORE_CFLAGS="-FQtCore"
-			export QT4_CORE_LIBS="-framework QtCore"
-			export QT4_FRONTEND_CFLAGS="-FQtGui"
-			export QT4_FRONTEND_LIBS="-framework QtGui"
+		if [ "$configure_qt_frameworks" = "yes" ]; then
+			export QT_CORE_CFLAGS="-FQtCore"
+			export QT_CORE_LIBS="-framework QtCore"
+			export QT_FRONTEND_CFLAGS="-FQtGui"
+			export QT_FRONTEND_LIBS="-framework QtGui"
 			CPPFLAGS="${CPPFLAGS} -I${SDKROOT}/Library/Frameworks/QtCore.framework/Headers"
 			CPPFLAGS="${CPPFLAGS} -I${SDKROOT}/Library/Frameworks/QtGui.framework/Headers"
 		fi
@@ -633,10 +706,10 @@ build_lyx() {
 		export LDFLAGS
 		echo CPPFLAGS="${CPPFLAGS}"
 		export CPPFLAGS
-		echo CONFIGURE_OPTIONS="${LyXConfigureOptions}" ${QtInstallDir:+"--with-qt4-dir=${QtInstallDir}"}
+		echo CONFIGURE_OPTIONS="${LyXConfigureOptions}" ${QtInstallDir:+"--with-qt-dir=${QtInstallDir}"}
 		"${LyxSourceDir}/configure"\
 			--prefix="${LyxAppPrefix}" --with-version-suffix="-${LyXVersionSuffix}"\
-			${QtInstallDir:+"--with-qt4-dir=${QtInstallDir}"} \
+			${QtInstallDir:+"--with-qt-dir=${QtInstallDir}"} \
 			${LyXConfigureOptions}\
 			--enable-build-type=rel && \
 		make ${MAKEJOBS} && make install${strip}
@@ -645,7 +718,7 @@ build_lyx() {
 				mv "${LYX_BUNDLE_PATH}/${file}"\
 					"${LYX_BUNDLE_PATH}/${file}-${arch}" 
 			else
-				echo ERROR: Cannot build and install LyX for ${arch}.
+				echo ERROR: Cannot build and install ${file} for ${arch}.
 				exit 1
 			fi
 		done
@@ -659,20 +732,43 @@ content_directory() {
 	echo "${content}"
 }
 
+installname() {
+		echo install_name_tool "$@"
+		install_name_tool "$@" || exit 1
+}
+
 private_framework() {
-	fwdir=$(framework_name "$1")
-	source="$2"
-	target="$3"
+	fwname="$1" ; shift
+	source="$1" ; shift
+	target="$1" ; shift
+	version=$(echo ${1:-"1.1.1"}.1.1.1 | cut -d. -f1-3) ; shift
+	fwdir=$(framework_name "${fwname}")
 	condir=$(content_directory "${target}")
 	libnm=$(basename "${source}")
-	mkdir -p "${condir}/${fwdir}"
-	if [ ! -f "${condir}/${fwdir}/${libnm}" ]; then
-		cp -p "${source}" "${condir}/${fwdir}"
-		echo Set library id in "${condir}/${fwdir}/${libnm}"
-		install_name_tool -id "@executable_path/../${fwdir}/${libnm}" "${condir}/${fwdir}/${libnm}"
+	libid="org.lyx."$(echo "${libnm}" | cut -d. -f1)
+	svrsn=$(echo "${version}" | cut -d. -f1-2)
+	fwvrsn="1"
+	mkdir -p "${condir}/${fwdir}"/Versions/${fwvrsn}/Headers
+	mkdir -p "${condir}/${fwdir}"/Versions/${fwvrsn}/Resources
+	if [ ! -f "${condir}/${fwdir}/Versions/${fwvrsn}/${fwname}" ]; then
+		cp -p "${source}" "${condir}/${fwdir}/Versions/${fwvrsn}/${fwname}"
+		for hfile in "$@" ; do
+			test -f "${hfile}" && cp -p "${hfile}" "${condir}/${fwdir}"/Versions/${fwvrsn}/Headers
+		done
+		ln -s ${fwvrsn} "${condir}/${fwdir}/Versions/Current"
+		ln -s Versions/Current/Headers "${condir}/${fwdir}/Headers"
+		ln -s Versions/Current/Resources "${condir}/${fwdir}/Resources"
+		ln -s Versions/Current/"${fwname}" "${condir}/${fwdir}/${fwname}"
+		installname -id "@executable_path/../${fwdir}/${fwname}" "${condir}/${fwdir}/${fwname}"
+		if [ -f "${LyxSourceDir}"/development/LyX-Mac-frameworks-template.plist ]; then
+			cat "${LyxSourceDir}"/development/LyX-Mac-frameworks-template.plist | sed \
+				-e "s/@CFBundleExecutable@/${fwname}/" \
+				-e "s/@CFBundleIdentifier@/${libid}/" \
+				-e "s/@CFBundleShortVersionString@/${svrsn}/" \
+				-e "s/@CFBundleVersion@/${version}/" > "${condir}/${fwdir}"/Resources/Info.plist
+		fi
 	fi
-	echo Correct library id reference to "${libnm}" in "${target}"
-	install_name_tool -change "${source}" "@executable_path/../${fwdir}/${libnm}" "${target}"
+	installname -change "${source}" "@executable_path/../${fwdir}/${fwname}" "${target}"
 }
 
 deploy_qtlibs() {
@@ -705,16 +801,20 @@ EOF
 		test -d "${condir}/${fwdir}" || (
 			echo Copy framework "${source}/lib/"$(basename "${fwdir}")
 			cp -pR "${source}/lib/"$(basename "${fwdir}") "${condir}/${fwdir}"
-			echo Set library id in "${condir}/${fwdir}/${version}${libnm}"
-			install_name_tool -id "@executable_path/../${fwdir}/${version}${libnm}" "${condir}/${fwdir}/${version}${libnm}"
+			rm -f "${condir}/${fwdir}/${libnm}"_debug "${condir}/${fwdir}/${version}${libnm}"_debug
+			test -f "${condir}/${fwdir}/${libnm}".prl && mv "${condir}/${fwdir}/${libnm}".prl "${condir}/${fwdir}"/Resources
+			test -f "${condir}/${fwdir}/${libnm}"_debug.prl && mv "${condir}/${fwdir}/${libnm}"_debug.prl "${condir}/${fwdir}"/Resources
+			installname -id "@executable_path/../${fwdir}/${version}${libnm}" "${condir}/${fwdir}/${version}${libnm}"
 			find "${condir}/PlugIns" "${condir}/"$(dirname "${fwdir}") -name Headers -prune -o -type f -print | while read filename ; do
 				if [ "${filename}" != "${target}" ]; then
 					otool -L "${filename}" 2>/dev/null | sort -u | while read library ; do
-						# pattern match for: /path/to/qt4/lib/QtGui.framework/Versions/4/QtGui (compatibility version 4.6.0, current version 4.6.2)
+						# pattern match for: /path/to/qt/lib/QtGui.framework/Versions/4/QtGui (compatibility version 4.6.0, current version 4.6.2)
 						case "${library}" in
+						*@rpath/*"${libnm}"*"("*version*")"*)
+							echo rpath based name for ${libnm} is ok.
+							;;
 						*"${libnm}"*"("*version*")"*)
-							echo Correct library id reference to "${libnm}" in "${filename}"
-							install_name_tool -change\
+							installname -change\
 								"${source}/lib/${dirname}/${version}${libnm}"\
 								"@executable_path/../${fwdir}/${version}${libnm}"\
 								"${filename}"
@@ -724,17 +824,18 @@ EOF
 				fi
 			done
 		)
-		echo Correct library id reference to "${libnm}" in "${target}"
-		install_name_tool -change\
+		installname -change\
 			"${source}/lib/${dirname}/${version}${libnm}"\
 			"@executable_path/../${fwdir}/${version}${libnm}"\
 			"${target}"
 	done
-	if [ ! -d "${condir}/translations" ]; then
-		mkdir -p "${condir}/translations"
+	if [ -d "${source}"/translations ]; then
+		if [ ! -d "${condir}/translations" ]; then
+			mkdir -p "${condir}/translations"
+		fi
+		echo Copy Qt translations to "${condir}/translations"
+		cp -p "${source}"/translations/qt_*.qm "${condir}/translations"
 	fi
-	echo Copy Qt translations to "${condir}/translations"
-	cp -p "${source}"/translations/qt_*.qm "${condir}/translations"
 }
 
 # -------------------------
@@ -752,16 +853,19 @@ convert_universal() {
 		if [ -n "${OBJ_LIST}" ]; then
 			lipo -create ${OBJ_LIST} -o "${BUNDLE_PATH}/${file}"
 		fi
-		if [ -f "${GettextInstallDir}/lib/${GettextLibrary}" -a "yes" = "${gettext_deployment}" ]; then
-			private_framework Gettext "${GettextInstallDir}/lib/${GettextLibrary}" "${LYX_BUNDLE_PATH}/${file}"
+		if [ -f "${LibMagicInstallDir}/lib/${LibMagicLibrary}" -a "yes" = "${libmagic_deployment}" ]; then
+			private_framework LibMagic "${LibMagicInstallDir}/lib/${LibMagicLibrary}" "${LYX_BUNDLE_PATH}/${file}" \
+				"${LibMagicVersion}" "${LibMagicInstallHdr}"
 		fi
 		if [ -f "${ASpellInstallDir}/lib/${ASpellLibrary}" -a "yes" = "${aspell_deployment}" ]; then
-			private_framework Aspell "${ASpellInstallDir}/lib/${ASpellLibrary}" "${LYX_BUNDLE_PATH}/${file}"
+			private_framework Aspell "${ASpellInstallDir}/lib/${ASpellLibrary}" "${LYX_BUNDLE_PATH}/${file}" \
+				"${ASpellVersion}" "${ASpellInstallHdr}"
 		fi
 		if [ -f "${HunSpellInstallDir}/lib/${HunSpellLibrary}" -a "yes" = "${hunspell_deployment}" ]; then
-			private_framework Hunspell "${HunSpellInstallDir}/lib/${HunSpellLibrary}" "${LYX_BUNDLE_PATH}/${file}"
+			private_framework Hunspell "${HunSpellInstallDir}/lib/${HunSpellLibrary}" "${LYX_BUNDLE_PATH}/${file}" \
+				"${HunSpellVersion}" "${HunSpellInstallDir}/include/hunspell/"*.hxx "${HunSpellInstallHdr}"
 		fi
-		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt4_deployment}" ]; then
+		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt_deployment}" ]; then
 			deploy_qtlibs "${LYX_BUNDLE_PATH}/${file}"
 		fi
 		otool -L "${BUNDLE_PATH}/${file}" | while read reference ; do
@@ -773,7 +877,59 @@ convert_universal() {
 		done
 	done
 	for arch in ${ARCH_LIST} ; do
-		rm -f ${BUNDLE_PATH}/*-${arch}
+		rm -f "${BUNDLE_PATH}"/*-${arch}
+	done
+}
+
+# -------------------------
+# Create code sign signatures
+# -------------------------
+code_sign() {
+	target="$1"
+	condir=$(content_directory "${target}"/lyx)
+	appdir=$(dirname "${condir}")
+	# have to sign frameworks first
+	for fwname in Aspell Hunspell LibMagic ; do
+		fwitem="${condir}"/$(framework_name "${fwname}")
+		if [ -d "${fwitem}" ]; then
+			codesign --verbose --force --sign "${CODESIGN_IDENTITY}" "${fwitem}"
+		fi
+	done
+	for csitem in \
+		"${condir}"/Frameworks/Qt*.framework/Versions/${QtFrameworkVersion} \
+		"${condir}"/PlugIns/*/lib*.dylib \
+		"${condir}"/Library/Spotlight/* \
+		"${target}"/inkscape \
+		"${target}"/maxima \
+		"${target}"/tex2lyx \
+		"${target}"/lyxeditor \
+		"${target}"/lyxconvert \
+		"${target}"/lyxclient
+	do
+		codesign --verbose --force --sign "${CODESIGN_IDENTITY}" "${csitem}"
+	done
+
+	/usr/bin/codesign --verbose --force --sign "${CODESIGN_IDENTITY}" "${appdir}" || {
+		echo Warning: codesign failed with certificate named '"'${CODESIGN_IDENTITY}'"'
+	}
+}
+
+deduplicate() {
+	find "$@" -type f -print | while read file ; do
+		echo $(md5 -q "$file") "$file"
+	done | sort | while read hash file ; do
+		ppath=$(dirname "$pfile")
+		path=$(dirname "$file")
+		if [ "$phash" = "$hash" -a "$ppath" = "$path" ]; then
+			pname=$(basename "$pfile")
+			name=$(basename "$file")
+			cmp -s "$pfile" "$file" && (
+				rm "$file"
+				cd "$path" && ln -s "$pname" "$name" && echo link for "$file" created
+			)
+		fi
+		phash="$hash"
+		pfile="$file"
 	done
 }
 
@@ -792,11 +948,13 @@ copy_dictionaries() {
 		HunSpellResources="${LyxAppPrefix}/Contents/Resources"
 		if [ -d "${DictionarySourceDir}" ]; then
 			( cd "${DictionarySourceDir}" && find dicts -name .svn -prune -o -type f -print | cpio -pmdv "${HunSpellResources}" )
+			deduplicate "${HunSpellResources}"/dicts
 		fi
 	fi
 	if [ -d "${DictionarySourceDir}" -a "yes" = "${thesaurus_deployment}" ]; then
 		MyThesResources="${LyxAppPrefix}/Contents/Resources"
 		( cd "${DictionarySourceDir}" && find thes -name .svn -prune -o -type f -print | cpio -pmdv "${MyThesResources}" )
+		deduplicate "${MyThesResources}"/thes
 	fi
 }
 
@@ -853,31 +1011,31 @@ make_dmg() {
 
 	hdiutil create -type SPARSE -size ${DMGSIZE:-"250m"} -fs HFS+ -volname "${LyxBase}" "${DMGNAME}"
 	# Unmount currently mounted disk image
-	test -d /Volumes/"${LyxBase}" && umount /Volumes/"${LyxBase}"
+	mount | grep "${LyxBase}" && umount /Volumes/"${LyxBase}"
+	test -d /Volumes/"${LyxBase}" && rmdir /Volumes/"${LyxBase}"
 
 	# Mount the disk image
-	hdiutil attach "${DMGNAME}.sparseimage"
+	DEVICES=$(hdiutil attach "${DMGNAME}.sparseimage" | cut -f 1)
 
 	# Obtain device information
-	DEVS=$(hdiutil attach "${DMGNAME}.sparseimage" | cut -f 1)
-	DEV=$(echo $DEVS | cut -f 1 -d ' ')
-	VOLUME=$(mount |grep ${DEV} | cut -f 3 -d ' ')
+	DEVICE=$(echo $DEVICES | cut -f 1 -d ' ')
+	VOLUME=$(mount |grep ${DEVICE} | cut -f 3 -d ' ')
 
 	# copy in the application bundle
-	cp -Rp "${LyxAppDir}.app" "${VOLUME}/${LyxName}.app"
+	ditto --hfsCompression "${LyxAppPrefix}" "${VOLUME}/${LyxName}.app"
 
 	# copy in background image
 	mkdir -p "${VOLUME}/Pictures"
-	cp "${DmgBackground}" "${VOLUME}/Pictures/background.png"
+	ditto --hfsCompression "${DmgBackground}" "${VOLUME}/Pictures/background.png"
 	# symlink applications
 	ln -s /Applications/ "${VOLUME}"/Applications
-	test -d "${DocumentationDir}" && cp -r "${DocumentationDir}" "${VOLUME}"
+	test -d "${DocumentationDir}" && ditto --hfsCompression "${DocumentationDir}" "${VOLUME}"
 	set_bundle_display_options "${VOLUME}" ${BG_W} ${BG_H}
-	${XCODE_DEVELOPER}/Tools/SetFile -a C "${VOLUME}"
+	PATH="${XCODE_DEVELOPER}/Tools:$PATH" SetFile -a C "${VOLUME}"
 	mv "${VOLUME}/Pictures" "${VOLUME}/.Pictures"
 
 	# Unmount the disk image
-	hdiutil detach ${DEV}
+	hdiutil detach ${DEVICE}
 
 	# Convert the disk image to read-only
 	hdiutil convert "${DMGNAME}.sparseimage" -format UDBZ -o "${DMGNAME}.dmg"
@@ -893,12 +1051,18 @@ build_package() {
 		cd "${LyxAppPrefix}" && zip -r "${LyxAppZip}" .
 	)
 
+	DMGARCH=""
+	for arch in ${ARCH_LIST} ; do
+		DMGARCH="${DMGARCH}-${arch}"
+	done
+	QtDmgArchSuffix=${QtMajorVersion}${DMGARCH}${QtAPI}.dmg
+
 	test -n "${DMGLocation}" && (
 		make_dmg "${DMGLocation}"
-		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt4_deployment}" ]; then
-			rm -f "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
-			echo move to "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
-			mv "${DMGLocation}/${DMGNAME}.dmg" "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
+		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt_deployment}" ]; then
+			rm -f "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
+			echo move to "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
+			mv "${DMGLocation}/${DMGNAME}.dmg" "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
 		fi
 	)
 }
@@ -911,5 +1075,7 @@ if [ ${LyxOnlyPackage:-"no"} = "no" ]; then
 	build_lyx
 	convert_universal
 	copy_dictionaries
+	test -n "${CODESIGN_IDENTITY}" && code_sign "${LYX_BUNDLE_PATH}"
+	find "${LyxAppPrefix}" -type d -exec chmod go-w '{}' \;
 fi
 build_package
